@@ -3,5 +3,5 @@ from django.utils.translation import pgettext_lazy
 
 
 class RedirectsConfig(AppConfig):
-    name = 'redirects'
+    name = 'ok_redirects'
     verbose_name = pgettext_lazy("ok:redirects", "Redirects")
